Skip to contents

Uses ggplot2 to create a generic volcano plot from the differential expression table generated by Seurat

Usage

make_volcano_plot(
  de_table,
  significant = TRUE,
  logfc = TRUE,
  pval = TRUE,
  label = 50
)

Arguments

de_table

Differential expression table generated by Seurat containing p_val, pct.1, pct.2 avg_log2FC and p_val_adj

significant

Boolean to color genes that meet both logfc and p-value thresholds

logfc

Boolean to color genes meeting logfc threshold of 1.5

pval

Boolean to color genes meeting p-value threshold of 0.05

label

Numeric value of top n genes to label, or a character vector of genes to label. Set label to NULL to generate unlabeled plot

Value

Returns a volcano plot as a ggplot2 object