calc_prelim_stats: Calculates initial statistics for a Seurat object as required for downstream analysis
calc_prelim_stats.RdCalculates the percentage of mitochondrial and ribosomal reads for each cell in the Seurat object. These statistics can be used for filtering or for feature regression in downstream normalization.