cluster_metrics: Calculates clustering metric scores
cluster_metrics.RdUses the ClusterSim package to calculate metrics for cluster consistency. These metrics do not require a priori knowledge of the truth set, which makes them ideal for scRNA clustering.
Arguments
- so
A Seurat single cell RNA (scRNA) object
- cluster_list
A vector of cluster resolution names (e.g. "SCT_snn_res.0.2")
- dims
An integer vector of the principal components to be used in calculating the cluster metrics. May not exceed the number of principal components available
- reduction
A string for the reduction to be used in calculating scores
- silhouette
A Boolean for whether to include silhouette scoring