convert_mtx_to_h5: Converts the triple .mtx files from single cell experiments to a .h5 counts file
convert_mtx_to_h5.RdUses existing tools to generate .h5 files, which can be easier to import or transfer
Details
Older versions of CellRanger, in addition to some other single cell alignment tools, such as PipSeq and DropSeq, produce a trio of files in an output director that pointed to all the necessary features:
matrix.mtx.gz: A matrix counts file with cells in the columns and features in the rows
barcodes.tsv.gz: A tab-separated file with cell/droplet barcode sequences
features.tsv.gz: A tab-separated file with gene names (or other features)