fetch_celldex_ref.Rd
Retrieves one of the 7 available references in celldex. Should be cache-agnostic by declaring the cache location as the local working directory
fetch_celldex_ref(ref_name, cache = ".")
Character string to be used for retrieving references from the celldex package
Character string to identify cache download location
A celldex single cell object in SCE data structure