preprocess_sample: Performs an initial preprocess on a Seurat object
preprocess_sample.RdConducts preliminary normalization/scaling, cell cycle scoring, and clustering on a Seurat single cell object
Details
The function performs the following processes on the data:assay
Cell cycle scoring
Normalization and scaling of RNA counts with log normalization
Normalization and scaling of RNA counts with SCTransform
Principal components analysis, neighbor identification, UMAP dimensionality reduction and preliminary clustering (through
seurat_clusteringfunction)