run_singleR_db.Rd
Uses the run_singleR function with the provided default human or mouse references
run_singleR_db(so_in, species)
A given Seurat single cell object
Indicates human (hg19 or hg38) or mouse (mm10) references to be used
A Seurat single cell object with predicted cell type annotations